==> haskell-hslua-objectorientation-2.3.0-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-6iiA11RLv7oI0ccORgFle0
key:                  hslua-objectorientation-2.3.0-6iiA11RLv7oI0ccORgFle0
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  58ff4015540c6d254ad844058db76034
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-6iiA11RLv7oI0ccORgFle0
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-42MeyWskp7m28w9nbHTnSC
    hslua-marshalling-2.3.1-1OCX1RaAq776jFXJrf9Og6
    hslua-typing-0.1.1-AZUjrGlumnALsQi4EjX643 mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-objectorientation-2.3.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-ERvPTRs8rXRCPW8SSxbte5
key:                  hslua-objectorientation-2.3.0-ERvPTRs8rXRCPW8SSxbte5
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  9ab2732c09bf1586317621dbb248199d
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-ERvPTRs8rXRCPW8SSxbte5
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 hslua-core-2.3.1-2dRTywdQScBHZUrGyNfFJc
    hslua-marshalling-2.3.1-E2obxYoMjMPCLtKQPN1IO6
    hslua-typing-0.1.1-1la9lv1SBmjInPk3EClAcw mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
